@@ -151,7 +151,8 @@ GtkBuilder *anjuta_util_builder_new (const gchar *filename, GError **error);
 gboolean anjuta_util_builder_get_objects (GtkBuilder *builder, const gchar *first_widget,...);
 
 /* Helper for drag and drop */
-GSList *anjuta_util_drop_get_files (GtkSelectionData *selection_data);
+GSList *anjuta_utils_drop_get_files (GtkSelectionData *selection_data);
+GPtrArray *anjuta_util_clone_string_gptrarray (const GPtrArray* source);
 
 /* Temporarily copied here */
 
