@@ -19,9 +19,8 @@
 */
 
 #include <config.h>
-#include <gtk/gtkactiongroup.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
@@ -31,7 +30,7 @@
 #include "plugin.h"
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-file-wizard.ui"
-#define ICON_FILE "anjuta-file-wizard-plugin.png"
+#define ICON_FILE "anjuta-file-wizard-plugin-48.png"
 
 static gpointer parent_class;
 
@@ -47,7 +46,7 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	
 	if (root_uri)
 	{
-		gchar *root_dir = gnome_vfs_get_local_path_from_uri (root_uri);
+		gchar *root_dir = anjuta_util_get_local_path_from_uri (root_uri);
 		if (root_dir)
 			w_plugin->top_dir = g_strdup(root_dir);
 		else
@@ -75,7 +74,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	AnjutaFileWizardPlugin *w_plugin;
 	static gboolean initialized = FALSE;
 	
-	DEBUG_PRINT ("AnjutaFileWizardPlugin: Activating File wizard plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaFileWizardPlugin: Activating File wizard plugin ...");
 	w_plugin = ANJUTA_PLUGIN_FILE_WIZARD (plugin);
 	w_plugin->prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
 	
