@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-pkg-config-chooser.h>
 #include <libanjuta/interfaces/ianjuta-iterable.h>
 #include <libanjuta/interfaces/ianjuta-document.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
@@ -51,6 +52,8 @@
 #define PREFS_BUILDER PACKAGE_DATA_DIR"/glade/anjuta-language-cpp-java.ui"
 #define ICON_FILE "anjuta-language-cpp-java-plugin.png"
 
+#define FIXME_DEFAULT_PACKAGE_VERSION		"1.0"
+
 /* Preferences keys */
 
 #define PREF_SCHEMA "org.gnome.anjuta.cpp"
@@ -847,9 +850,9 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 	gboolean line_checked_for_comment = FALSE;
 
     /* Determine whether or not to add multi-line comment asterisks */
-	gchar* comment_continued = " * ";
-	IAnjutaIterable* line_begin = ianjuta_editor_get_line_begin_position (editor, line_num, NULL);
-	IAnjutaIterable* line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
+	const gchar *comment_continued = " * ";
+	IAnjutaIterable *line_begin = ianjuta_editor_get_line_begin_position (editor, line_num, NULL);
+	IAnjutaIterable  *line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
 
 	*incomplete_statement = -1;
 	*line_indent_spaces = 0;
@@ -978,9 +981,11 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 							 * only if it does not already exist there. The purpose of this fix is to avoid
 							 * extra " * " on auto-indent. */
 
-							if (g_settings_get_boolean (plugin->settings, PREF_COMMENT_LEADING_ASTERISK) &&
-									ianjuta_iterable_compare (line_end, line_begin, NULL) == 0)
+							if ((g_settings_get_boolean (plugin->settings, PREF_COMMENT_LEADING_ASTERISK)) &&
+								(ianjuta_iterable_compare (line_end, line_begin, NULL)) == 0)
+							{
 								ianjuta_editor_insert (editor, line_begin, comment_continued, -1, NULL);
+							}
 
 							/* In the middle of a comment we can't know
 						     * if the statement is incomplete
@@ -1014,7 +1019,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 						while (ianjuta_iterable_previous (prev, NULL))
 						{
 							prev_c = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (prev), 0,
-															  NULL);
+															  	   NULL);
 							if (!isspace(prev_c))
 								break;
 							if (iter_is_newline (prev, prev_c))
@@ -1122,8 +1127,8 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 				line_indent = get_line_indentation (editor, line_for_indent);
 				line_indent += extra_indent;
 
-				(*line_indent_spaces) += g_settings_get_boolean (plugin->settings,
-				                                                 PREF_INDENT_PARANTHESE_SIZE);
+				(*line_indent_spaces) += g_settings_get_int (plugin->settings,
+				                                             PREF_INDENT_PARANTHESE_SIZE);
 			}
 			
 			/* Although statement is incomplete at this point, we don't
@@ -1428,6 +1433,22 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 	return line_indent;
 }
 
+static void on_editor_char_inserted_cpp (IAnjutaEditor *editor,
+                                         IAnjutaIterable *insert_pos,
+                                         gchar ch,
+                                         CppJavaPlugin *plugin);
+
+static void
+insert_editor_blocked (IAnjutaEditor* editor,
+                       IAnjutaIterable* iter,
+                       gchar* text,
+                       CppJavaPlugin* plugin)
+{
+	g_signal_handlers_block_by_func (editor, on_editor_char_inserted_cpp, plugin);
+	ianjuta_editor_insert (editor, iter, text, -1, NULL);
+	g_signal_handlers_unblock_by_func (editor, on_editor_char_inserted_cpp, plugin);
+}
+
 static void
 on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 							 IAnjutaIterable *insert_pos,
@@ -1525,12 +1546,12 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 				switch (ch)
 				{
 					case '[': 
-							  ianjuta_editor_insert (editor, iter,
-													 "]", 1, NULL);
+							  insert_editor_blocked (editor, iter,
+													 "]", plugin);
 							  break;
 					case '(': 
-							  ianjuta_editor_insert (editor, iter,
-													 ")", 1, NULL);
+							  insert_editor_blocked (editor, iter,
+													 ")", plugin);
 							  break;
 					default: 
 						       break;
@@ -1570,7 +1591,7 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 					else c = g_strdup ("'");
 					
 					ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (editor), NULL);
-					ianjuta_editor_insert (editor, iter, c, 1, NULL);
+					insert_editor_blocked (editor, iter, c, plugin);
 					ianjuta_editor_goto_position (editor, iter, NULL);
 					ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (editor), NULL);	
 					
@@ -2035,6 +2056,7 @@ cpp_java_plugin_class_init (GObjectClass *klass)
 #define PREF_WIDGET_SPACE "preferences_toggle:bool:1:1:cpp-completion-space-after-func"
 #define PREF_WIDGET_BRACE "preferences_toggle:bool:1:1:cpp-completion-brace-after-func"
 #define PREF_WIDGET_AUTO "preferences_toggle:bool:1:1:cpp-completion-enable"
+#define PREF_WIDGET_PKG_CONFIG "pkg_config_chooser1"
 
 static void
 on_autocompletion_toggled (GtkToggleButton* button,
@@ -2049,6 +2071,47 @@ on_autocompletion_toggled (GtkToggleButton* button,
 	gtk_widget_set_sensitive (widget, sensitive);
 }
 
+static void
+on_package_activated (AnjutaPkgConfigChooser *self, const gchar* package,
+    				  gpointer data)
+{
+	CppJavaPlugin* plugin;
+	IAnjutaSymbolManager *isymbol_manager;
+
+	plugin = ANJUTA_PLUGIN_CPP_JAVA (data);
+
+	DEBUG_PRINT ("activated %s", package);
+	isymbol_manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
+												IAnjutaSymbolManager,
+												NULL);
+	
+	ianjuta_symbol_manager_activate_package (isymbol_manager, 
+	    									 package, 
+    							  			 FIXME_DEFAULT_PACKAGE_VERSION,
+    							  			 NULL);
+	
+}
+
+static void
+on_package_deactivated (AnjutaPkgConfigChooser *self, const gchar* package,
+    					gpointer data)
+{
+	CppJavaPlugin* plugin;
+	IAnjutaSymbolManager *isymbol_manager;
+
+	plugin = ANJUTA_PLUGIN_CPP_JAVA (data);
+
+	DEBUG_PRINT ("deactivated %s", package);
+
+	isymbol_manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
+												IAnjutaSymbolManager,
+												NULL);
+	ianjuta_symbol_manager_deactivate_package (isymbol_manager, 
+	    									 package, 
+    							  			 FIXME_DEFAULT_PACKAGE_VERSION,
+    							  			 NULL);
+}
+
 static void
 ipreferences_merge (IAnjutaPreferences* ipref, AnjutaPreferences* prefs,
 					GError** e)
@@ -2057,6 +2120,7 @@ ipreferences_merge (IAnjutaPreferences* ipref, AnjutaPreferences* prefs,
 	CppJavaPlugin* plugin = ANJUTA_PLUGIN_CPP_JAVA (ipref);
 	plugin->bxml = gtk_builder_new ();
 	GtkWidget* toggle;
+	GtkWidget* pkg_config;
 		
 	/* Add preferences */
 	if (!gtk_builder_add_from_file (plugin->bxml, PREFS_BUILDER, &error))
@@ -2072,6 +2136,17 @@ ipreferences_merge (IAnjutaPreferences* ipref, AnjutaPreferences* prefs,
 	g_signal_connect (toggle, "toggled", G_CALLBACK (on_autocompletion_toggled),
 	                  plugin->bxml);
 	on_autocompletion_toggled (GTK_TOGGLE_BUTTON (toggle), plugin->bxml);
+
+	pkg_config = GTK_WIDGET (gtk_builder_get_object (plugin->bxml, PREF_WIDGET_PKG_CONFIG));
+	anjuta_pkg_config_chooser_show_active_column (ANJUTA_PKG_CONFIG_CHOOSER (pkg_config), 
+	    										  TRUE);
+	g_signal_connect (G_OBJECT (pkg_config), "package-activated",
+					  G_CALLBACK (on_package_activated), plugin);
+
+	g_signal_connect (G_OBJECT (pkg_config), "package-deactivated",
+					  G_CALLBACK (on_package_deactivated), plugin);
+	
+	gtk_widget_show_all (pkg_config);
 }
 
 static void
