@@ -48,7 +48,6 @@
 #include <gtksourceview/gtksourcelanguage.h>
 #include <gtksourceview/gtksourcelanguagemanager.h>
 #include <gtksourceview/gtksourcebuffer.h>
-#include <gtksourceview/gtksourceiter.h>
 #include <gtksourceview/gtksourcecompletionitem.h>
 
 #include "config.h"
@@ -89,10 +88,12 @@ static gboolean on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 
 #define MARKER_PIXMAP_LINEMARKER "anjuta-linemark-16.png"
 #define MARKER_PIXMAP_PROGRAM_COUNTER "anjuta-pcmark-16.png"
+#define MARKER_PIXMAP_MESSAGE "anjuta-message-16.png"
 #define MARKER_PIXMAP_BREAKPOINT_DISABLED "anjuta-breakpoint-disabled-16.png"
 #define MARKER_PIXMAP_BREAKPOINT_ENABLED "anjuta-breakpoint-enabled-16.png"
 #define MARKER_PIXMAP_BOOKMARK "anjuta-bookmark-16.png"
 
+#define MARKER_TOOLTIP_DATA "__tooltip"
 
 /* Keep in sync with IAnjutaMarkableMarker */
 
@@ -100,6 +101,7 @@ static const gchar* marker_types [] =
 {
 	"sv-linemarker",
 	"sv-bookmark",
+	"sv-message",
 	"sv-breakpoint-enabled",
 	"sv-breakpoint-disabled",
 	"sv-program-counter",
@@ -133,54 +135,49 @@ anjuta_message_area_new (const gchar    *text,
 	return GTK_WIDGET (message_area);
 }
 
-/* Create pixmaps for the markers */
-static void sourceview_create_markers(Sourceview* sv)
+static gchar*
+on_marker_tooltip (GtkSourceMarkCategory* cat, GtkSourceMark* mark, gpointer data)
+{
+	//Sourceview* sv = ANJUTA_SOURCEVIEW (data);
+	gchar* tooltip;
+	tooltip = g_object_get_data (G_OBJECT (mark), MARKER_TOOLTIP_DATA);
+	if (tooltip)
+		return g_strdup (tooltip);
+	else
+		return NULL;
+}
+
+static void 
+sourceview_create_marker_category (Sourceview* sv, const gchar* marker_pixbuf,
+                                   IAnjutaMarkableMarker marker_type)
 {
 	GdkPixbuf * pixbuf;
 	GtkSourceView* view = 	GTK_SOURCE_VIEW(sv->priv->view);
+	if ((pixbuf = gdk_pixbuf_new_from_file (marker_pixbuf, NULL)))
+	{
+		GtkSourceMarkCategory* cat = gtk_source_view_get_mark_category (view, marker_types[marker_type]);
+		gtk_source_mark_category_set_pixbuf (cat, pixbuf);
+		gtk_source_mark_category_set_priority (cat, marker_type);
+		g_signal_connect (cat, "query-tooltip-text", G_CALLBACK (on_marker_tooltip), sv);
+		g_object_unref (pixbuf);
+	}
+}
 
-	
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BOOKMARK, NULL)))
-	{
-		gtk_source_view_set_mark_category_icon_from_pixbuf (view, 
-		    marker_types[IANJUTA_MARKABLE_BOOKMARK], pixbuf);
-		gtk_source_view_set_mark_category_priority (view, marker_types [IANJUTA_MARKABLE_BOOKMARK],
-											 IANJUTA_MARKABLE_BOOKMARK);
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BREAKPOINT_DISABLED, NULL)))
-	{
-		gtk_source_view_set_mark_category_icon_from_pixbuf (view, 
-			marker_types[IANJUTA_MARKABLE_BREAKPOINT_DISABLED], pixbuf);
-		gtk_source_view_set_mark_category_priority (view, marker_types [IANJUTA_MARKABLE_BREAKPOINT_DISABLED],
-											 IANJUTA_MARKABLE_BREAKPOINT_DISABLED);
-
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BREAKPOINT_ENABLED, NULL)))
-	{
-		gtk_source_view_set_mark_category_icon_from_pixbuf (view, 
-			marker_types[IANJUTA_MARKABLE_BREAKPOINT_ENABLED], pixbuf);
-		gtk_source_view_set_mark_category_priority (view, marker_types [IANJUTA_MARKABLE_BREAKPOINT_ENABLED],
-											 IANJUTA_MARKABLE_BREAKPOINT_ENABLED);
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_PROGRAM_COUNTER, NULL)))
-	{
-		gtk_source_view_set_mark_category_icon_from_pixbuf (view, 
-			marker_types[IANJUTA_MARKABLE_PROGRAM_COUNTER], pixbuf);
-		gtk_source_view_set_mark_category_priority (view, marker_types [IANJUTA_MARKABLE_PROGRAM_COUNTER],
-											 IANJUTA_MARKABLE_PROGRAM_COUNTER);
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_LINEMARKER, NULL)))
-	{
-		gtk_source_view_set_mark_category_icon_from_pixbuf (view, 
-			marker_types[IANJUTA_MARKABLE_LINEMARKER], pixbuf);
-		gtk_source_view_set_mark_category_priority (view, marker_types [IANJUTA_MARKABLE_LINEMARKER],
-											 IANJUTA_MARKABLE_LINEMARKER);
-		g_object_unref (pixbuf);
-	}
+/* Create pixmaps for the markers */
+static void sourceview_create_markers(Sourceview* sv)
+{
+	sourceview_create_marker_category (sv, PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BOOKMARK,
+	                                   IANJUTA_MARKABLE_BOOKMARK);
+	sourceview_create_marker_category (sv, PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BREAKPOINT_DISABLED,
+	                                   IANJUTA_MARKABLE_BREAKPOINT_DISABLED);
+	sourceview_create_marker_category (sv, PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BREAKPOINT_ENABLED,
+	                                   IANJUTA_MARKABLE_BREAKPOINT_ENABLED);
+	sourceview_create_marker_category (sv, PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_PROGRAM_COUNTER,
+	                                   IANJUTA_MARKABLE_PROGRAM_COUNTER);
+	sourceview_create_marker_category (sv, PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_LINEMARKER,
+	                                   IANJUTA_MARKABLE_LINEMARKER);
+	sourceview_create_marker_category (sv, PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_MESSAGE,
+	                                   IANJUTA_MARKABLE_MESSAGE);
 }
 
 #define PREF_COLOR_ERROR "msgman-color-error"
@@ -1783,6 +1780,7 @@ typedef struct
 	gint location;
 	gint handle;
 	guint source;
+	gchar* tooltip;
 	Sourceview* sv;
 } SVMark;
 
@@ -1795,6 +1793,7 @@ static gboolean mark_real (gpointer data)
 	const gchar* category;
 	gint location = svmark->location;
 	gint marker_count = svmark->handle;
+	gchar* tooltip = svmark->tooltip;
 	IAnjutaMarkableMarker marker = svmark->marker;
 	gchar* name;
 	
@@ -1813,6 +1812,8 @@ static gboolean mark_real (gpointer data)
 	
 	source_mark = gtk_source_buffer_create_source_mark(GTK_SOURCE_BUFFER(sv->priv->document), 
 												name, category, &iter);
+	g_object_set_data_full (G_OBJECT (source_mark), MARKER_TOOLTIP_DATA, tooltip,
+	                        (GDestroyNotify) g_free);
 	
 	g_source_remove (svmark->source);
 	
@@ -1823,7 +1824,7 @@ static gboolean mark_real (gpointer data)
 
 static gint
 imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
-		   GError **e)
+           const gchar* tooltip, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(mark);
 	SVMark* svmark = g_slice_new0 (SVMark);
@@ -1843,6 +1844,7 @@ imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 	svmark->location = location;
 	svmark->handle = marker_count;
 	svmark->marker = marker;
+	svmark->tooltip = tooltip ? g_strdup (tooltip) : NULL;
 	svmark->source = g_idle_add (mark_real, svmark);
 	
 	sv->priv->idle_sources = g_slist_prepend (sv->priv->idle_sources,
@@ -2338,7 +2340,7 @@ isearch_forward (IAnjutaEditorSearch* isearch,
 	
 	GtkTextIter result_start, result_end;
 	
-	GtkSourceSearchFlags flags = 0;
+	GtkTextSearchFlags flags = 0;
 
 	sourceview_cell_get_iter (start, &start_iter);
 	sourceview_cell_get_iter (end, &end_iter);
@@ -2346,7 +2348,7 @@ isearch_forward (IAnjutaEditorSearch* isearch,
 	
 	if (!case_sensitive)
 	{
-		flags = GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		flags = GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 	
 	gboolean result = 
@@ -2389,7 +2391,7 @@ isearch_backward (IAnjutaEditorSearch* isearch,
 	GtkTextIter end_iter;	
 	GtkTextIter result_start, result_end;
 	
-	GtkSourceSearchFlags flags = 0;
+	GtkTextSearchFlags flags = 0;
 	
 	sourceview_cell_get_iter (start, &start_iter);
 	sourceview_cell_get_iter (end, &end_iter);
@@ -2397,7 +2399,7 @@ isearch_backward (IAnjutaEditorSearch* isearch,
 	
 	if (!case_sensitive)
 	{
-		flags = GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		flags = GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 	
 	gboolean result = 
