@@ -14,8 +14,8 @@
  * for more details.
  * 
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc., 59 
- * Temple Place, Suite 330, Boston, MA  02111-1307  USA 
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
  */
 
 #ifndef _ANJUTA_H_
@@ -24,7 +24,8 @@
 #include <libanjuta/e-splash.h>
 #include "anjuta-app.h"
 
-AnjutaApp* anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
+AnjutaApp* anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
+					   gboolean no_session, gboolean no_files,
 					   const gchar *im_file, gboolean proper_shutdown,
 					   const gchar *geometry);
 
